@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -23,7 +23,7 @@ import { registerClusterConfigRoute } from './routes/api/clusterConfig';
 import { registerClusterInfoRoute } from './routes/api/clusterInfo';
 import { registerDevworkspacesRoutes } from './routes/api/devworkspaces';
 import { registerDevWorkspaceTemplates } from './routes/api/devworkspaceTemplates';
-import { registerDevworkspaceWebsocketWatcher } from './routes/api/devworkspaceWebsocketWatcher';
+import { registerWebsocket } from './routes/api/websocket';
 import { registerDockerConfigRoutes } from './routes/api/dockerConfig';
 import { registerKubeConfigRoute } from './routes/api/kubeConfig';
 import { registerNamespacesRoute } from './routes/api/namespaces';
@@ -33,6 +33,9 @@ import { registerYamlResolverRoute } from './routes/api/yamlResolver';
 import { registerFactoryAcceptanceRedirect } from './routes/factoryAcceptanceRedirect';
 import { registerWorkspaceRedirect } from './routes/workspaceRedirect';
 import { registerDevfileSchemaRoute } from './routes/api/devfileSchema';
+import { registerEventsRoutes } from './routes/api/events';
+import { registerPodsRoutes } from './routes/api/pods';
+import { registerDevworkspaceResourcesRoute } from './routes/api/devworkspaceResources';
 
 export default async function buildApp(server: FastifyInstance): Promise<void> {
   const cheHost = process.env.CHE_HOST as string;
@@ -72,7 +75,7 @@ export default async function buildApp(server: FastifyInstance): Promise<void> {
 
   registerWorkspaceRedirect(server);
 
-  registerDevworkspaceWebsocketWatcher(server);
+  registerWebsocket(server);
 
   // swagger and API
   registerSwagger(server);
@@ -91,6 +94,10 @@ export default async function buildApp(server: FastifyInstance): Promise<void> {
 
   registerDockerConfigRoutes(server);
 
+  registerEventsRoutes(server);
+
+  registerPodsRoutes(server);
+
   registerKubeConfigRoute(server);
 
   registerServerConfigRoute(server);
@@ -100,4 +107,6 @@ export default async function buildApp(server: FastifyInstance): Promise<void> {
   registerYamlResolverRoute(server);
 
   registerDevfileSchemaRoute(server);
+
+  registerDevworkspaceResourcesRoute(server);
 }
