@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,8 +14,10 @@ import * as k8s from '@kubernetes/client-node';
 import { DevWorkspaceApiService } from './services/devWorkspaceApi';
 import { DevWorkspaceTemplateApiService } from './services/devWorkspaceTemplateApi';
 import { DockerConfigApiService } from './services/dockerConfigApi';
+import { EventApiService } from './services/eventApi';
 import { KubeConfigApiService } from './services/kubeConfigApi';
 import { NamespaceApiService } from './services/namespaceApi';
+import { PodApiService } from './services/podAPI';
 import { ServerConfigApiService } from './services/serverConfigApi';
 import { UserProfileApiService } from './services/userProfileApi';
 import {
@@ -23,8 +25,10 @@ import {
   IDevWorkspaceClient,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
+  IEventApi,
   IKubeConfigApi,
   INamespaceApi,
+  IPodApi,
   IServerConfigApi,
   IUserProfileApi,
 } from './types';
@@ -38,6 +42,14 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
     this.kubeConfig = kc;
   }
 
+  get eventApi(): IEventApi {
+    return new EventApiService(this.kubeConfig);
+  }
+
+  get podApi(): IPodApi {
+    return new PodApiService(this.kubeConfig);
+  }
+
   get devWorkspaceTemplateApi(): IDevWorkspaceTemplateApi {
     return new DevWorkspaceTemplateApiService(this.kubeConfig);
   }
