@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,18 +10,19 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import * as k8s from '@kubernetes/client-node';
-import { IDevWorkspaceList, IDevWorkspaceApi, IDevWorkspaceCallbacks } from '../types';
 import {
   devworkspaceGroup,
   devworkspaceLatestVersion,
   devworkspacePlural,
   V1alpha2DevWorkspace,
 } from '@devfile/api';
-
 import { api } from '@eclipse-che/common';
+import * as k8s from '@kubernetes/client-node';
+import { V1Status } from '@kubernetes/client-node';
+import http, { IncomingHttpHeaders } from 'http';
+import { MessageListener } from '../../services/types/Observer';
+import { IDevWorkspaceApi } from '../types';
 import { createError } from './helpers/createError';
-import { isLocalRun } from '../../localRun';
 import { CustomObjectAPI, prepareCustomObjectAPI } from './helpers/prepareCustomObjectAPI';
 import { prepareCustomObjectWatch } from './helpers/prepareCustomObjectWatch';
 
@@ -30,13 +31,14 @@ const DEV_WORKSPACE_API_ERROR_LABEL = 'CUSTOM_OBJECTS_API_ERROR';
 export class DevWorkspaceApiService implements IDevWorkspaceApi {
   private readonly customObjectAPI: CustomObjectAPI;
   private readonly customObjectWatch: k8s.Watch;
+  private stopWatch?: () => void;
 
   constructor(kc: k8s.KubeConfig) {
     this.customObjectAPI = prepareCustomObjectAPI(kc);
     this.customObjectWatch = prepareCustomObjectWatch(kc);
   }
 
-  async listInNamespace(namespace: string): Promise<IDevWorkspaceList> {
+  async listInNamespace(namespace: string): Promise<api.IDevWorkspaceList> {
     try {
       const resp = await this.customObjectAPI.listNamespacedCustomObject(
         devworkspaceGroup,
@@ -44,7 +46,7 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
         namespace,
         devworkspacePlural,
       );
-      return resp.body as IDevWorkspaceList;
+      return resp.body as api.IDevWorkspaceList;
     } catch (e) {
       throw createError(e, DEV_WORKSPACE_API_ERROR_LABEL, 'Unable to list devworkspaces');
     }
@@ -69,10 +71,21 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
     }
   }
 
+  private propagateHeaders(resp: { response: http.IncomingMessage; body: unknown }) {
+    const propagateHeaders = ['warning'];
+    const headers = Object.entries(resp.response.headers).reduce((acc, [key, value]) => {
+      if (propagateHeaders.includes(key)) {
+        acc[key] = value;
+      }
+      return acc;
+    }, {} as Partial<IncomingHttpHeaders>);
+    return headers;
+  }
+
   async create(
     devworkspace: V1alpha2DevWorkspace,
     namespace: string,
-  ): Promise<V1alpha2DevWorkspace> {
+  ): Promise<{ devWorkspace: V1alpha2DevWorkspace; headers: Partial<IncomingHttpHeaders> }> {
     try {
       if (!devworkspace.metadata?.name && !devworkspace.metadata?.generateName) {
         throw new Error(
@@ -87,46 +100,14 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
         devworkspacePlural,
         devworkspace,
       );
-      return resp.body as V1alpha2DevWorkspace;
+      const devWorkspace = resp.body as V1alpha2DevWorkspace;
+      const headers = this.propagateHeaders(resp);
+      return { devWorkspace, headers };
     } catch (e) {
       throw createError(e, DEV_WORKSPACE_API_ERROR_LABEL, 'Unable to create devworkspace');
     }
   }
 
-  async update(devworkspace: V1alpha2DevWorkspace): Promise<V1alpha2DevWorkspace> {
-    try {
-      if (!devworkspace.metadata?.name || !devworkspace.metadata?.namespace) {
-        throw new Error('DevWorkspace.metadata with name and namespace are required');
-      }
-
-      // you have to delete some elements from the devworkspace in order to update
-      if (devworkspace.metadata?.uid) {
-        devworkspace.metadata.uid = undefined;
-      }
-      if (devworkspace.metadata?.creationTimestamp) {
-        delete devworkspace.metadata.creationTimestamp;
-      }
-      if (devworkspace.metadata?.deletionTimestamp) {
-        delete devworkspace.metadata.deletionTimestamp;
-      }
-
-      const name = devworkspace.metadata.name;
-      const namespace = devworkspace.metadata.namespace;
-
-      const resp = await this.customObjectAPI.replaceNamespacedCustomObject(
-        devworkspaceGroup,
-        devworkspaceLatestVersion,
-        namespace,
-        devworkspacePlural,
-        name,
-        devworkspace,
-      );
-      return resp.body as V1alpha2DevWorkspace;
-    } catch (e) {
-      throw createError(e, DEV_WORKSPACE_API_ERROR_LABEL, 'Unable to update devworkspace');
-    }
-  }
-
   async delete(namespace: string, name: string): Promise<void> {
     try {
       await this.customObjectAPI.deleteNamespacedCustomObject(
@@ -152,11 +133,7 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
     namespace: string,
     name: string,
     patches: api.IPatch[],
-  ): Promise<V1alpha2DevWorkspace> {
-    return this.createPatch(namespace, name, patches);
-  }
-
-  private async createPatch(namespace: string, name: string, patches: api.IPatch[]) {
+  ): Promise<{ devWorkspace: V1alpha2DevWorkspace; headers: Partial<IncomingHttpHeaders> }> {
     try {
       const options = {
         headers: {
@@ -175,7 +152,9 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
         undefined,
         options,
       );
-      return resp.body as V1alpha2DevWorkspace;
+      const devWorkspace = resp.body as V1alpha2DevWorkspace;
+      const headers = this.propagateHeaders(resp);
+      return { devWorkspace, headers };
     } catch (e) {
       throw createError(e, DEV_WORKSPACE_API_ERROR_LABEL, 'Unable to patch devworkspace');
     }
@@ -184,50 +163,45 @@ export class DevWorkspaceApiService implements IDevWorkspaceApi {
   async watchInNamespace(
     namespace: string,
     resourceVersion: string,
-    callbacks: IDevWorkspaceCallbacks,
-  ): Promise<{ abort: () => void }> {
+    listener: MessageListener,
+  ): Promise<void> {
     const path = `/apis/${devworkspaceGroup}/${devworkspaceLatestVersion}/watch/namespaces/${namespace}/${devworkspacePlural}`;
     const queryParams = { watch: true, resourceVersion };
 
-    return this.customObjectWatch.watch(
+    this.stopWatching();
+
+    const request: http.ServerResponse = await this.customObjectWatch.watch(
       path,
       queryParams,
-      (type: string, devworkspace: V1alpha2DevWorkspace) => {
-        if (type === 'ADDED') {
-          callbacks.onAdded(devworkspace);
-        } else if (type === 'MODIFIED') {
-          callbacks.onModified(devworkspace);
-        } else if (type === 'DELETED') {
-          const workspaceId = devworkspace?.status?.devworkspaceId;
-          if (workspaceId) {
-            callbacks.onDeleted(workspaceId);
-          } else {
-            // workspace does not have id yet, means it's not processed by DWO yet
+      (eventPhase: string, apiObj: V1alpha2DevWorkspace | V1Status) => {
+        switch (eventPhase) {
+          case api.webSocket.EventPhase.ADDED:
+          case api.webSocket.EventPhase.MODIFIED:
+          case api.webSocket.EventPhase.DELETED: {
+            const devWorkspace = apiObj as V1alpha2DevWorkspace;
+            listener({ eventPhase, devWorkspace });
+            break;
+          }
+          case api.webSocket.EventPhase.ERROR: {
+            const status = apiObj as V1Status;
+            listener({ eventPhase, status });
+            break;
           }
-        } else if (type === 'ERROR') {
-          callbacks.onError('Error: Unknown error.');
-        } else {
-          callbacks.onError(`Error: Unknown type '${type}'.`);
         }
       },
-      (error: any) => {
-        let message;
-        if (error && error.message) {
-          message = error.message;
-        } else {
-          if (isLocalRun()) {
-            // unexpected error format. Log it and expose to user what we can
-            console.log('Unexpected error', error);
-          }
-          if (error) {
-            message = error.toString();
-          }
-          if (!message) {
-            message = 'unknown. Contact admin to check server logs';
-          }
-        }
-        callbacks.onError(`Error: ${message}`);
+      (error: unknown) => {
+        console.error(`[ERROR] Stopped watching ${path}. Reason:`, error);
       },
     );
+
+    this.stopWatch = () => request.destroy();
+  }
+
+  /**
+   * Stop watching DevWorkspaces.
+   */
+  public stopWatching(): void {
+    this.stopWatch?.();
+    this.stopWatch = undefined;
   }
 }
