@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -13,10 +13,12 @@
 import {
   V1alpha2DevWorkspace,
   V1alpha2DevWorkspaceTemplate,
-  V220DevfileComponents,
+  V221DevfileComponents,
 } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
+import { MessageListener } from '../../services/types/Observer';
+import { IncomingHttpHeaders } from 'http';
 
 /**
  * Holds the methods for working with dockerconfig for devworkspace
@@ -41,38 +43,24 @@ export interface INamespaceApi {
   getNamespaces(token: string): Promise<Array<string>>;
 }
 
-export interface IDevWorkspaceApi {
+export interface IDevWorkspaceApi extends IWatcherService {
   /**
    * Get the DevWorkspace with given namespace in the specified namespace
    */
   getByName(namespace: string, name: string): Promise<V1alpha2DevWorkspace>;
 
   /**
-   * Get list of devworkspaces in the given namespace
+   * Get list of DevWorkspaces in the given namespace
    */
-  listInNamespace(namespace: string): Promise<IDevWorkspaceList>;
+  listInNamespace(namespace: string): Promise<api.IDevWorkspaceList>;
 
   /**
-   * Listen to all DevWorkspaces changes in the given namespace
-   * @param namespace namespace where to listen to DevWorkspaces changes
-   * @param resourceVersion special mark that all changes up to a given resourceVersion have already been sent
-   * @param callbacks callback will be invoked when change happens
+   * Create a DevWorkspace based on the specified configuration.
    */
-  watchInNamespace(
+  create(
+    devWorkspace: V1alpha2DevWorkspace,
     namespace: string,
-    resourceVersion: string,
-    callbacks: IDevWorkspaceCallbacks,
-  ): Promise<{ abort: () => void }>;
-
-  /**
-   * Create a devworkspace based on the specified configuration.
-   */
-  create(devworkspace: V1alpha2DevWorkspace, namespace: string): Promise<V1alpha2DevWorkspace>;
-
-  /**
-   * Updates the DevWorkspace with the given configuration
-   */
-  update(devworkspace: V1alpha2DevWorkspace): Promise<V1alpha2DevWorkspace>;
+  ): Promise<{ devWorkspace: V1alpha2DevWorkspace; headers: Partial<IncomingHttpHeaders> }>;
 
   /**
    * Delete the DevWorkspace with given name in the specified namespace
@@ -82,7 +70,25 @@ export interface IDevWorkspaceApi {
   /**
    * Patches the DevWorkspace with given name in the specified namespace
    */
-  patch(namespace: string, name: string, patches: api.IPatch[]): Promise<V1alpha2DevWorkspace>;
+  patch(
+    namespace: string,
+    name: string,
+    patches: api.IPatch[],
+  ): Promise<{ devWorkspace: V1alpha2DevWorkspace; headers: Partial<IncomingHttpHeaders> }>;
+}
+
+export interface IEventApi extends IWatcherService {
+  /**
+   * Get list of Events in the given namespace
+   */
+  listInNamespace(namespace: string): Promise<api.IEventList>;
+}
+
+export interface IPodApi extends IWatcherService {
+  /**
+   * Get list of Pods in the given namespace
+   */
+  listInNamespace(namespace: string): Promise<api.IPodList>;
 }
 
 export interface IDevWorkspaceTemplateApi {
@@ -112,7 +118,7 @@ export type CustomResourceDefinitionSpecDevEnvironments = {
   containerBuildConfiguration?: {
     openShiftSecurityContextConstraint?: string;
   };
-  defaultComponents?: V220DevfileComponents[];
+  defaultComponents?: V221DevfileComponents[];
   defaultEditor?: string;
   defaultPlugins?: api.IWorkspacesDefaultPlugins[];
   disableContainerBuildCapabilities?: boolean;
@@ -167,7 +173,7 @@ export interface IServerConfigApi {
    * Returns the default components applied to DevWorkspaces.
    * These default components are meant to be used when a Devfile does not contain any components.
    */
-  getDefaultComponents(cheCustomResource: CustomResourceDefinition): V220DevfileComponents[];
+  getDefaultComponents(cheCustomResource: CustomResourceDefinition): V221DevfileComponents[];
   /**
    * Returns the openVSX URL.
    */
@@ -221,14 +227,8 @@ export interface IUserProfileApi {
   getUserProfile(namespace: string): Promise<api.IUserProfile | undefined>;
 }
 
-export type IDevWorkspaceCallbacks = {
-  onModified: (workspace: V1alpha2DevWorkspace) => void;
-  onDeleted: (workspaceId: string) => void;
-  onAdded: (workspace: V1alpha2DevWorkspace) => void;
-  onError: (error: string) => void;
-};
-
 export interface IDevWorkspaceClient {
+  eventApi: IEventApi;
   devworkspaceApi: IDevWorkspaceApi;
   devWorkspaceTemplateApi: IDevWorkspaceTemplateApi;
   dockerConfigApi: IDockerConfigApi;
@@ -238,11 +238,21 @@ export interface IDevWorkspaceClient {
   userProfileApi: IUserProfileApi;
 }
 
-export interface IDevWorkspaceList {
-  apiVersion: string;
-  kind: string;
-  metadata: {
-    resourceVersion?: string;
-  };
-  items: V1alpha2DevWorkspace[];
+export interface IWatcherService {
+  /**
+   * Listen to objects changes in the given namespace
+   * @param namespace namespace where to listen to Events changes
+   * @param resourceVersion special mark that all changes up to a given resourceVersion have already been sent
+   * @param listener callback will be invoked when change happens
+   */
+  watchInNamespace(
+    namespace: string,
+    resourceVersion: string,
+    listener: MessageListener,
+  ): Promise<void>;
+
+  /**
+   * Stop watching objects changes in the given namespace
+   */
+  stopWatching(): void;
 }
