@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,9 +11,13 @@
  */
 
 import { FastifyInstance } from 'fastify';
-import fastifyHttpProxy from '@fastify/http-proxy';
 import { stubCheServerOptionsRequests } from '../hooks/stubCheServerOptionsRequests';
 
+// to workaround the issue with TextEncoder
+import { TextEncoder } from 'util';
+(global as any).TextEncoder = TextEncoder;
+import fastifyHttpProxy from '@fastify/http-proxy';
+
 export function registerCheApiProxy(
   server: FastifyInstance,
   cheApiProxyUpstream: string,
