@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -15,13 +15,13 @@
 import {
   V1alpha2DevWorkspace,
   V1alpha2DevWorkspaceTemplate,
-  V220DevfileComponents,
+  V221DevfileComponents,
 } from '@devfile/api';
 import { api } from '@eclipse-che/common';
+import { IncomingHttpHeaders } from 'http';
 import {
   DevWorkspaceClient,
   IDevWorkspaceApi,
-  IDevWorkspaceList,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
   IKubeConfigApi,
@@ -34,7 +34,7 @@ export const stubContainerBuild = {
   disableContainerBuildCapabilities: true,
 };
 export const stubDashboardWarning = 'Dashboard warning';
-export const stubDefaultComponents: V220DevfileComponents[] = [];
+export const stubDefaultComponents: V221DevfileComponents[] = [];
 export const stubDefaultEditor = undefined;
 export const stubDefaultPlugins: api.IWorkspacesDefaultPlugins[] = [];
 export const stubOpenVSXURL = 'openvsx-url';
@@ -45,7 +45,7 @@ export const stubWorkspaceInactivityTimeout = 0;
 export const stubWorkspaceRunTimeout = 0;
 export const stubWorkspaceStartupTimeout = 0;
 
-export const stubDevWorkspacesList: IDevWorkspaceList = {
+export const stubDevWorkspacesList: api.IDevWorkspaceList = {
   apiVersion: 'workspace.devfile.io/v1alpha2',
   kind: 'DevWorkspaceList',
   metadata: {
@@ -57,6 +57,7 @@ export const stubDevWorkspace: V1alpha2DevWorkspace = {
   apiVersion: 'workspace.devfile.io/v1alpha2',
   kind: 'DevWorkspace',
 };
+export const stubHeaders: IncomingHttpHeaders = {};
 
 export const stubDevWorkspaceTemplatesList = [
   {
@@ -96,11 +97,13 @@ export function getDevWorkspaceClient(_args: Parameters<typeof helper>): ReturnT
       getWorkspaceStartTimeout: _cheCustomResource => stubWorkspaceStartupTimeout,
     } as IServerConfigApi,
     devworkspaceApi: {
-      create: (_devworkspace, _namespace) => Promise.resolve(stubDevWorkspace),
+      create: (_devworkspace, _namespace) =>
+        Promise.resolve({ devWorkspace: stubDevWorkspace, headers: stubHeaders }),
       delete: (_namespace, _name) => Promise.resolve(undefined),
       getByName: (_namespace, _name) => Promise.resolve(stubDevWorkspace),
       listInNamespace: _namespace => Promise.resolve(stubDevWorkspacesList),
-      patch: (_namespace, _name, _patches) => Promise.resolve(stubDevWorkspace),
+      patch: (_namespace, _name, _patches) =>
+        Promise.resolve({ devWorkspace: stubDevWorkspace, headers: stubHeaders }),
     } as IDevWorkspaceApi,
     dockerConfigApi: {
       read: _namespace => Promise.resolve(stubDockerConfig),
