@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -20,9 +20,6 @@ import { IssueComponent } from '../Issue';
 
 const brandingData = {
   name: 'Product Name',
-  docs: {
-    certificate: 'certificate/troubleshooting/location',
-  },
 } as BrandingData;
 const issue = {
   type: 'unknown',
