@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -30,14 +30,6 @@ export class LoaderProgress extends React.PureComponent<Props> {
     this.wizardRef = React.createRef();
   }
 
-  public componentDidUpdate(): void {
-    const { currentStepId } = this.props;
-    const wizardCurrent = this.wizardRef.current;
-    if (wizardCurrent?.state?.currentStep !== currentStepId) {
-      wizardCurrent.state.currentStep = currentStepId;
-    }
-  }
-
   render(): React.ReactNode {
     const { currentStepId, steps } = this.props;
 
