@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,40 +10,40 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { Action, Store } from 'redux';
-import { Provider } from 'react-redux';
+import { api } from '@eclipse-che/common';
+import { StateMock } from '@react-mock/state';
 import { screen, waitFor, within } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
 import { createMemoryHistory, MemoryHistory } from 'history';
-import { ROUTE } from '../../../../../../../Routes/routes';
-import { FakeStoreBuilder } from '../../../../../../../store/__mocks__/storeBuilder';
-import { DevWorkspaceBuilder } from '../../../../../../../store/__mocks__/devWorkspaceBuilder';
-import { ActionCreators } from '../../../../../../../store/Workspaces';
-import { AppThunk } from '../../../../../../../store';
+import { dump } from 'js-yaml';
+import React from 'react';
+import { Provider } from 'react-redux';
+import { Action, Store } from 'redux';
+import StepApplyDevfile, { State } from '..';
 import { List, LoaderStep, LoadingStep } from '../../../../../../../components/Loader/Step';
 import {
   buildLoaderSteps,
   getFactoryLoadingSteps,
 } from '../../../../../../../components/Loader/Step/buildSteps';
+import { ROUTE } from '../../../../../../../Routes/routes';
 import devfileApi from '../../../../../../../services/devfileApi';
 import getComponentRenderer from '../../../../../../../services/__mocks__/getComponentRenderer';
-import StepApplyDevfile, { State } from '..';
+import { AppThunk } from '../../../../../../../store';
+import { ActionCreators } from '../../../../../../../store/Workspaces';
+import { DevWorkspaceBuilder } from '../../../../../../../store/__mocks__/devWorkspaceBuilder';
+import { FakeStoreBuilder } from '../../../../../../../store/__mocks__/storeBuilder';
+import { buildFactoryParams } from '../../../../../buildFactoryParams';
 import {
   FACTORY_URL_ATTR,
   MIN_STEP_DURATION_MS,
   POLICIES_CREATE_ATTR,
-  TIMEOUT_TO_CREATE_SEC,
   REMOTES_ATTR,
+  TIMEOUT_TO_CREATE_SEC,
 } from '../../../../../const';
-import userEvent from '@testing-library/user-event';
-import { StateMock } from '@react-mock/state';
-import buildFactoryParams from '../../../../buildFactoryParams';
 import { prepareDevfile } from '../prepareDevfile';
-import { dump } from 'js-yaml';
-import { api } from '@eclipse-che/common';
 
 jest.mock('../prepareDevfile.ts');
-jest.mock('../../../../../../../pages/Loader/Factory');
+jest.mock('../../../../../../../pages/Loader');
 
 const mockCreateWorkspaceFromDevfile = jest.fn().mockResolvedValue(undefined);
 jest.mock('../../../../../../../store/Workspaces/index', () => {
@@ -64,9 +64,10 @@ let history: MemoryHistory;
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
+const mockOnTabChange = jest.fn();
 
 const stepId = LoadingStep.CREATE_WORKSPACE__APPLY_DEVFILE.toString();
-const currentStepIndex = 4;
+const currentStepIndex = 5;
 const loadingSteps = getFactoryLoadingSteps('devfile');
 
 const factoryUrl = 'https://factory-url';
@@ -240,8 +241,8 @@ describe('Factory Loader container, step CREATE_WORKSPACE__APPLYING_DEVFILE', ()
       );
 
       expect(dashboardDevfile.projects).not.toBe(undefined);
-      expect(dashboardDevfile.projects!.length).toBe(1);
-      expect(dashboardDevfile.projects![0]).toMatchObject({
+      expect(dashboardDevfile.projects?.length).toBe(1);
+      expect(dashboardDevfile.projects?.[0]).toMatchObject({
         git: {
           checkoutFrom: {
             remote: 'origin',
@@ -281,8 +282,8 @@ describe('Factory Loader container, step CREATE_WORKSPACE__APPLYING_DEVFILE', ()
       );
 
       expect(dashboardDevfile.projects).not.toBe(undefined);
-      expect(dashboardDevfile.projects!.length).toBe(1);
-      expect(dashboardDevfile.projects![0]).toMatchObject({
+      expect(dashboardDevfile.projects?.length).toBe(1);
+      expect(dashboardDevfile.projects?.[0]).toMatchObject({
         git: {
           checkoutFrom: {
             remote: 'origin',
@@ -334,8 +335,8 @@ describe('Factory Loader container, step CREATE_WORKSPACE__APPLYING_DEVFILE', ()
       );
 
       expect(dashboardDevfile.projects).not.toBe(undefined);
-      expect(dashboardDevfile.projects!.length).toBe(1);
-      expect(dashboardDevfile.projects![0]).toMatchObject({
+      expect(dashboardDevfile.projects?.length).toBe(1);
+      expect(dashboardDevfile.projects?.[0]).toMatchObject({
         git: {
           checkoutFrom: {
             remote: 'origin',
@@ -375,8 +376,8 @@ describe('Factory Loader container, step CREATE_WORKSPACE__APPLYING_DEVFILE', ()
       );
 
       expect(dashboardDevfile.projects).not.toBe(undefined);
-      expect(dashboardDevfile.projects!.length).toBe(1);
-      expect(dashboardDevfile.projects![0]).toMatchObject({
+      expect(dashboardDevfile.projects?.length).toBe(1);
+      expect(dashboardDevfile.projects?.[0]).toMatchObject({
         git: {
           checkoutFrom: {
             remote: 'origin',
@@ -656,6 +657,40 @@ describe('Factory Loader container, step CREATE_WORKSPACE__APPLYING_DEVFILE', ()
 
     expect(hasError.textContent).toEqual('false');
   });
+
+  test('handle warning when creating a workspace', async () => {
+    const devWorkspace = new DevWorkspaceBuilder()
+      .withUID('workspace-uid')
+      .withName(devfileName)
+      .withNamespace('user-che')
+      .build();
+    const warningMessage = 'This is a warning';
+
+    const store = getStoreBuilder()
+      .withFactoryResolver({
+        resolver: {},
+        converted: {
+          devfileV2: devfile,
+        },
+      })
+      .withDevWorkspaces({
+        workspaces: [devWorkspace],
+        warnings: { 'workspace-uid': warningMessage },
+      })
+      .build();
+
+    renderComponent(store, loaderSteps, searchParams, currentStepIndex);
+
+    jest.advanceTimersByTime(MIN_STEP_DURATION_MS);
+
+    await waitFor(() => expect(screen.getByText(`Warning: ${warningMessage}`)).toBeTruthy());
+
+    await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
+
+    const currentStep = screen.getByTestId(stepId);
+    const hasError = within(currentStep).getByTestId('hasError');
+    expect(hasError.textContent).toEqual('false');
+  });
 });
 
 function getStoreBuilder(): FakeStoreBuilder {
@@ -683,6 +718,7 @@ function getComponent(
       tabParam={undefined}
       onNextStep={mockOnNextStep}
       onRestart={mockOnRestart}
+      onTabChange={mockOnTabChange}
     />
   );
   if (localStorage) {
