@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { safeDump } from 'js-yaml';
+import { dump } from 'js-yaml';
 import { cloneDeep } from 'lodash';
 import { DevWorkspaceTemplate } from '../../../../../../services/devfileApi/devfileApi';
 import { DevWorkspace } from '../../../../../../services/devfileApi/devWorkspace';
@@ -33,7 +33,7 @@ export default function prepareResources(
   if (!metadata.annotations) {
     metadata.annotations = {};
   }
-  metadata.annotations[DEVWORKSPACE_DEVFILE_SOURCE] = safeDump({
+  metadata.annotations[DEVWORKSPACE_DEVFILE_SOURCE] = dump({
     factory: { params: factoryId },
   });
 
@@ -81,4 +81,14 @@ function addSuffix(devWorkspace: DevWorkspace, devWorkspaceTemplate: DevWorkspac
 
   // update DevWorkspaceTemplate name
   devWorkspaceTemplate.metadata.name = editorPluginName + suffix;
+
+  // update DevWorkspace contribution name
+  const contributions = devWorkspace.spec.contributions;
+  if (contributions && contributions.length > 0) {
+    contributions.forEach(contribution => {
+      if (contribution.name === 'editor' && contribution.kubernetes) {
+        contribution.kubernetes.name = editorPluginName + suffix;
+      }
+    });
+  }
 }
