@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,17 +10,16 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { AlertVariant } from '@patternfly/react-core';
 import { helpers } from '@eclipse-che/common';
-import { DisposableCollection } from '../../../../../services/helpers/disposable';
+import { AlertVariant } from '@patternfly/react-core';
+import React from 'react';
+import { LoaderPage } from '../../../../../pages/Loader';
 import { delay } from '../../../../../services/helpers/delay';
-import { FactoryLoaderPage } from '../../../../../pages/Loader/Factory';
-import { MIN_STEP_DURATION_MS } from '../../../const';
-import { FactoryParams } from '../../types';
-import buildFactoryParams from '../../buildFactoryParams';
-import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
+import { DisposableCollection } from '../../../../../services/helpers/disposable';
 import { AlertItem } from '../../../../../services/helpers/types';
+import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
+import { buildFactoryParams, FactoryParams } from '../../../buildFactoryParams';
+import { MIN_STEP_DURATION_MS } from '../../../const';
 
 export type Props = LoaderStepProps & {
   searchParams: URLSearchParams;
@@ -86,11 +85,13 @@ export default class StepCreateWorkspace extends AbstractLoaderStep<Props, State
     const alertItem = this.getAlertItem(lastError);
 
     return (
-      <FactoryLoaderPage
+      <LoaderPage
         alertItem={alertItem}
         currentStepId={currentStepId}
         steps={steps}
         tabParam={tabParam}
+        workspace={undefined}
+        onTabChange={tab => this.handleTabChange(tab)}
       />
     );
   }
