@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,34 +10,34 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { Action, Store } from 'redux';
-import { Provider } from 'react-redux';
-import { createMemoryHistory } from 'history';
+import { StateMock } from '@react-mock/state';
+import { cleanup, screen, waitFor, within } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
-import { screen, waitFor, within, cleanup } from '@testing-library/react';
-import { FakeStoreBuilder } from '../../../../../../../store/__mocks__/storeBuilder';
-import { ActionCreators, OAuthResponse } from '../../../../../../../store/FactoryResolver';
-import { AppThunk } from '../../../../../../../store';
+import { createMemoryHistory } from 'history';
+import React from 'react';
+import { Provider } from 'react-redux';
+import { Action, Store } from 'redux';
+import StepFetchDevfile, { State, UnsupportedGitProviderError } from '..';
 import { List, LoaderStep, LoadingStep } from '../../../../../../../components/Loader/Step';
 import {
   buildLoaderSteps,
   getFactoryLoadingSteps,
 } from '../../../../../../../components/Loader/Step/buildSteps';
 import devfileApi from '../../../../../../../services/devfileApi';
-import StepFetchDevfile, { State } from '..';
 import getComponentRenderer from '../../../../../../../services/__mocks__/getComponentRenderer';
+import { AppThunk } from '../../../../../../../store';
+import { ActionCreators, OAuthResponse } from '../../../../../../../store/FactoryResolver';
+import { FakeStoreBuilder } from '../../../../../../../store/__mocks__/storeBuilder';
+import { buildFactoryParams } from '../../../../../buildFactoryParams';
 import {
   FACTORY_URL_ATTR,
   MIN_STEP_DURATION_MS,
   OVERRIDE_ATTR_PREFIX,
-  TIMEOUT_TO_RESOLVE_SEC,
   REMOTES_ATTR,
+  TIMEOUT_TO_RESOLVE_SEC,
 } from '../../../../../const';
-import { StateMock } from '@react-mock/state';
-import buildFactoryParams from '../../../../buildFactoryParams';
 
-jest.mock('../../../../../../../pages/Loader/Factory');
+jest.mock('../../../../../../../pages/Loader');
 
 const mockRequestFactoryResolver = jest.fn();
 const mockIsOAuthResponse = jest.fn();
@@ -59,9 +59,10 @@ const { renderComponent } = getComponentRenderer(getComponent);
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
+const mockOnTabChange = jest.fn();
 
 const stepId = LoadingStep.CREATE_WORKSPACE__FETCH_DEVFILE.toString();
-const currentStepIndex = 2;
+const currentStepIndex = 3;
 const loadingSteps = getFactoryLoadingSteps('devfile');
 
 const factoryUrl = 'https://factory-url';
@@ -133,6 +134,24 @@ describe('Factory Loader container, step CREATE_WORKSPACE__FETCH_DEVFILE', () =>
     expect(mockOnRestart).toHaveBeenCalled();
   });
 
+  test('unsupported git provider', async () => {
+    const localState: Partial<State> = {
+      lastError: new UnsupportedGitProviderError('Failed to fetch devfile'),
+      factoryParams: buildFactoryParams(searchParams),
+    };
+    renderComponent(store, loaderSteps, searchParams, currentStepIndex, localState);
+
+    jest.advanceTimersByTime(MIN_STEP_DURATION_MS);
+
+    const defaultDevfileButton = await screen.findByRole('button', {
+      name: 'Continue with the default devfile',
+    });
+    expect(defaultDevfileButton).toBeDefined();
+    userEvent.click(defaultDevfileButton);
+
+    await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
+  });
+
   test('no project url, remotes exist', async () => {
     const store = new FakeStoreBuilder().build();
 
@@ -290,7 +309,12 @@ describe('Factory Loader container, step CREATE_WORKSPACE__FETCH_DEVFILE', () =>
       jest.advanceTimersByTime(MIN_STEP_DURATION_MS);
 
       await waitFor(() =>
-        expect(mockRequestFactoryResolver).toHaveBeenCalledWith(factoryUrl, expectedOverrideParams),
+        expect(mockRequestFactoryResolver).toHaveBeenCalledWith(
+          factoryUrl,
+          expect.objectContaining({
+            overrides: expectedOverrideParams,
+          }),
+        ),
       );
     });
 
@@ -563,6 +587,7 @@ function getComponent(
       tabParam={undefined}
       onNextStep={mockOnNextStep}
       onRestart={mockOnRestart}
+      onTabChange={mockOnTabChange}
     />
   );
   if (localState) {
