@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,33 +10,32 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { connect, ConnectedProps } from 'react-redux';
-import { isEqual } from 'lodash';
 import common, { helpers } from '@eclipse-che/common';
 import { AlertVariant } from '@patternfly/react-core';
-import { AppState } from '../../../../../../store';
-import * as FactoryResolverStore from '../../../../../../store/FactoryResolver';
-import { DisposableCollection } from '../../../../../../services/helpers/disposable';
-import { selectAllWorkspaces } from '../../../../../../store/Workspaces/selectors';
+import { isEqual } from 'lodash';
+import React from 'react';
+import { connect, ConnectedProps } from 'react-redux';
+import ExpandableWarning from '../../../../../../components/ExpandableWarning';
+import { LoaderPage } from '../../../../../../pages/Loader';
 import { delay } from '../../../../../../services/helpers/delay';
-import { FactoryLoaderPage } from '../../../../../../pages/Loader/Factory';
+import { DisposableCollection } from '../../../../../../services/helpers/disposable';
 import { getEnvironment, isDevEnvironment } from '../../../../../../services/helpers/environment';
+import { AlertItem } from '../../../../../../services/helpers/types';
+import OAuthService, { isOAuthResponse } from '../../../../../../services/oauth';
 import SessionStorageService, {
   SessionStorageKey,
 } from '../../../../../../services/session-storage';
+import { AppState } from '../../../../../../store';
+import * as FactoryResolverStore from '../../../../../../store/FactoryResolver';
 import {
   selectFactoryResolver,
   selectFactoryResolverConverted,
 } from '../../../../../../store/FactoryResolver/selectors';
-import buildStepTitle from './buildStepTitle';
-import { FactoryParams } from '../../../types';
-import { MIN_STEP_DURATION_MS, TIMEOUT_TO_RESOLVE_SEC } from '../../../../const';
-import buildFactoryParams from '../../../buildFactoryParams';
+import { selectAllWorkspaces } from '../../../../../../store/Workspaces/selectors';
 import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../../AbstractStep';
-import { AlertItem } from '../../../../../../services/helpers/types';
-import OAuthService, { isOAuthResponse } from '../../../../../../services/oauth';
-import ExpandableWarning from '../../../../../../components/ExpandableWarning';
+import { buildFactoryParams, FactoryParams } from '../../../../buildFactoryParams';
+import { MIN_STEP_DURATION_MS, TIMEOUT_TO_RESOLVE_SEC } from '../../../../const';
+import buildStepTitle from './buildStepTitle';
 
 export class ApplyingDevfileError extends Error {
   constructor(message) {
@@ -45,6 +44,13 @@ export class ApplyingDevfileError extends Error {
   }
 }
 
+export class UnsupportedGitProviderError extends Error {
+  constructor(message) {
+    super(message);
+    this.name = 'UnsupportedGitProviderError';
+  }
+}
+
 const RELOADS_LIMIT = 2;
 type ReloadsInfo = {
   [url: string]: number;
@@ -191,6 +197,9 @@ class StepFetchDevfile extends AbstractLoaderStep<Props, State> {
       if (errorMessage.includes('schema validation failed')) {
         throw new ApplyingDevfileError(errorMessage);
       }
+      if (errorMessage === 'Failed to fetch devfile') {
+        throw new UnsupportedGitProviderError(errorMessage);
+      }
       throw e;
     }
     if (!resolveDone) {
@@ -222,13 +231,9 @@ class StepFetchDevfile extends AbstractLoaderStep<Props, State> {
    */
   private async resolveDevfile(factoryUrl: string): Promise<boolean> {
     const { factoryParams } = this.state;
-    const params = Object.assign({}, factoryParams.overrides, {
-      error_code: factoryParams.errorCode,
-    });
 
     try {
-      OAuthService.setOauthStartedState();
-      await this.props.requestFactoryResolver(factoryUrl, params);
+      await this.props.requestFactoryResolver(factoryUrl, factoryParams);
       this.clearNumberOfTries();
       return true;
     } catch (e) {
@@ -327,6 +332,32 @@ class StepFetchDevfile extends AbstractLoaderStep<Props, State> {
         ],
       };
     }
+    if (error instanceof UnsupportedGitProviderError) {
+      return {
+        key: 'factory-loader-devfile-error',
+        title: 'Warning',
+        variant: AlertVariant.warning,
+        children: (
+          <ExpandableWarning
+            textBefore="Looking for a Devfile in the git repository failed."
+            errorMessage={helpers.errors.getMessage(error)}
+            textAfter="The git provider may not be supported by Eclipse Che (or the git server hasn't been configured
+            appropriately). Note that the git cloning of the repository will succeed if it's public or it's private
+            and the developer git credentials secret has been configured."
+          />
+        ),
+        actionCallbacks: [
+          {
+            title: 'Continue with the default devfile',
+            callback: () => this.handleDevfileError(),
+          },
+          {
+            title: 'Reload',
+            callback: () => this.clearStepError(),
+          },
+        ],
+      };
+    }
     if (!error) {
       return;
     }
@@ -359,11 +390,13 @@ class StepFetchDevfile extends AbstractLoaderStep<Props, State> {
     const alertItem = this.getAlertItem(lastError);
 
     return (
-      <FactoryLoaderPage
+      <LoaderPage
         alertItem={alertItem}
         currentStepId={currentStepId}
         steps={steps}
         tabParam={tabParam}
+        workspace={undefined}
+        onTabChange={tab => this.handleTabChange(tab)}
       />
     );
   }
