@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,29 +10,28 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import common from '@eclipse-che/common';
+import { AlertVariant } from '@patternfly/react-core';
+import { isEqual } from 'lodash';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { isEqual } from 'lodash';
-import { AlertVariant } from '@patternfly/react-core';
-import common from '@eclipse-che/common';
-import { AppState } from '../../../../../store';
-import { selectAllWorkspaces } from '../../../../../store/Workspaces/selectors';
-import * as WorkspaceStore from '../../../../../store/Workspaces';
-import WorkspaceLoaderPage from '../../../../../pages/Loader/Workspace';
-import { DisposableCollection } from '../../../../../services/helpers/disposable';
+import { LoaderPage } from '../../../../../pages/Loader';
+import { WorkspaceParams } from '../../../../../Routes/routes';
 import { delay } from '../../../../../services/helpers/delay';
+import { DisposableCollection } from '../../../../../services/helpers/disposable';
+import { AlertItem, LoaderTab } from '../../../../../services/helpers/types';
+import { Workspace } from '../../../../../services/workspace-adapter';
+import { AppState } from '../../../../../store';
+import * as WorkspaceStore from '../../../../../store/Workspaces';
+import { selectAllWorkspaces } from '../../../../../store/Workspaces/selectors';
+import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
 import { MIN_STEP_DURATION_MS, TIMEOUT_TO_GET_URL_SEC } from '../../../const';
 import findTargetWorkspace from '../../../findTargetWorkspace';
-import { Workspace } from '../../../../../services/workspace-adapter';
-import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
-import { AlertItem, LoaderTab } from '../../../../../services/helpers/types';
+import { isAvailableEndpoint } from '../../../../../services/helpers/api-ping';
 
 export type Props = MappedProps &
   LoaderStepProps & {
-    matchParams: {
-      namespace: string;
-      workspaceName: string;
-    };
+    matchParams: WorkspaceParams;
   };
 export type State = LoaderStepState;
 
@@ -89,7 +88,6 @@ class StepOpenWorkspace extends AbstractLoaderStep<Props, State> {
 
   protected async runStep(): Promise<boolean> {
     await delay(MIN_STEP_DURATION_MS);
-
     const { matchParams } = this.props;
     const workspace = this.findTargetWorkspace(this.props);
 
@@ -102,7 +100,6 @@ class StepOpenWorkspace extends AbstractLoaderStep<Props, State> {
     if (!workspace.isRunning) {
       throw new Error(`The workspace status changed unexpectedly to "${workspace.status}".`);
     }
-
     if (!workspace.ideUrl) {
       // wait for the IDE url to be set
       try {
@@ -117,7 +114,6 @@ class StepOpenWorkspace extends AbstractLoaderStep<Props, State> {
             },
           });
         });
-
         return false;
       } catch (e) {
         throw new Error(
@@ -126,9 +122,13 @@ class StepOpenWorkspace extends AbstractLoaderStep<Props, State> {
       }
     }
 
-    window.location.replace(workspace.ideUrl);
+    const isAvailable = await isAvailableEndpoint(workspace.ideUrl);
+    if (isAvailable) {
+      window.location.replace(workspace.ideUrl);
+      return true;
+    }
 
-    return true;
+    return false;
   }
 
   protected findTargetWorkspace(props: Props): Workspace | undefined {
@@ -168,12 +168,13 @@ class StepOpenWorkspace extends AbstractLoaderStep<Props, State> {
     const alertItem = this.getAlertItem(lastError);
 
     return (
-      <WorkspaceLoaderPage
+      <LoaderPage
         alertItem={alertItem}
         currentStepId={currentStepId}
         steps={steps}
         tabParam={tabParam}
         workspace={workspace}
+        onTabChange={tab => this.handleTabChange(tab)}
       />
     );
   }
