@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,29 +10,29 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { Action, Store } from 'redux';
-import { Provider } from 'react-redux';
-import { createMemoryHistory } from 'history';
-import userEvent from '@testing-library/user-event';
+import { api } from '@eclipse-che/common';
+import { StateMock } from '@react-mock/state';
 import { screen, waitFor, within } from '@testing-library/react';
-import { WorkspaceParams } from '../../../../../../Routes/routes';
-import { FakeStoreBuilder } from '../../../../../../store/__mocks__/storeBuilder';
-import { DevWorkspaceBuilder } from '../../../../../../store/__mocks__/devWorkspaceBuilder';
-import { ActionCreators } from '../../../../../../store/Workspaces';
-import { AppThunk } from '../../../../../../store';
+import userEvent from '@testing-library/user-event';
+import { createMemoryHistory } from 'history';
+import React from 'react';
+import { Provider } from 'react-redux';
+import { Action, Store } from 'redux';
+import StepStartWorkspace, { State } from '..';
 import { List, LoaderStep, LoadingStep } from '../../../../../../components/Loader/Step';
 import {
   buildLoaderSteps,
   getWorkspaceLoadingSteps,
 } from '../../../../../../components/Loader/Step/buildSteps';
-import { MIN_STEP_DURATION_MS } from '../../../../const';
+import { WorkspaceParams } from '../../../../../../Routes/routes';
 import getComponentRenderer from '../../../../../../services/__mocks__/getComponentRenderer';
-import StepStartWorkspace, { State } from '..';
-import { StateMock } from '@react-mock/state';
-import { api } from '@eclipse-che/common';
+import { AppThunk } from '../../../../../../store';
+import { ActionCreators } from '../../../../../../store/Workspaces';
+import { DevWorkspaceBuilder } from '../../../../../../store/__mocks__/devWorkspaceBuilder';
+import { FakeStoreBuilder } from '../../../../../../store/__mocks__/storeBuilder';
+import { MIN_STEP_DURATION_MS } from '../../../../const';
 
-jest.mock('../../../../../../pages/Loader/Workspace');
+jest.mock('../../../../../../pages/Loader');
 
 const mockStartWorkspace = jest.fn();
 jest.mock('../../../../../../store/Workspaces/index', () => {
@@ -49,6 +49,7 @@ jest.mock('../../../../../../store/Workspaces/index', () => {
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
+const mockOnTabChange = jest.fn();
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
@@ -778,6 +779,7 @@ function getComponent(
       tabParam={undefined}
       onNextStep={mockOnNextStep}
       onRestart={mockOnRestart}
+      onTabChange={mockOnTabChange}
     />
   );
   if (localState) {
