@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,44 +10,32 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { History } from 'history';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { History } from 'history';
-import { AppState } from '../../../store';
-import { selectAllWorkspaces, selectLogs } from '../../../store/Workspaces/selectors';
-import * as WorkspaceStore from '../../../store/Workspaces';
 import { List, LoaderStep, LoadingStep } from '../../../components/Loader/Step';
+import { WorkspaceParams } from '../../../Routes/routes';
+import { AppState } from '../../../store';
+import * as WorkspaceStore from '../../../store/Workspaces';
+import { selectAllWorkspaces } from '../../../store/Workspaces/selectors';
+import StepCheckRunningWorkspacesLimit from '../CommonSteps/CheckRunningWorkspacesLimit';
 import StepInitialize from './Steps/Initialize';
-import StepStartWorkspace from './Steps/StartWorkspace';
 import StepOpenWorkspace from './Steps/OpenWorkspace';
-import StepCheckRunningWorkspacesLimit from './Steps/CheckRunningWorkspacesLimit';
-import findTargetWorkspace from '../findTargetWorkspace';
+import StepStartWorkspace from './Steps/StartWorkspace';
 
 export type Props = MappedProps & {
   currentStepIndex: number; // not ID, but index
   history: History;
   loaderSteps: Readonly<List<LoaderStep>>;
-  matchParams: {
-    namespace: string;
-    workspaceName: string;
-  };
+  matchParams: WorkspaceParams;
   tabParam: string | undefined;
   onNextStep: () => void;
   onRestart: (tabName?: string) => void;
+  onTabChange: (tab: string) => void;
 };
 
 class WorkspaceLoader extends React.PureComponent<Props> {
-  constructor(props: Props) {
-    super(props);
-  }
-
   private handleWorkspaceRestart(tabName?: string): void {
-    const { allWorkspaces, matchParams } = this.props;
-    const workspace = findTargetWorkspace(allWorkspaces, matchParams);
-    if (workspace) {
-      this.props.deleteWorkspaceLogs(workspace);
-    }
-
     this.props.onRestart(tabName);
   }
 
@@ -89,7 +77,6 @@ class WorkspaceLoader extends React.PureComponent<Props> {
 
 const mapStateToProps = (state: AppState) => ({
   allWorkspaces: selectAllWorkspaces(state),
-  workspacesLogs: selectLogs(state),
 });
 
 const connector = connect(mapStateToProps, WorkspaceStore.actionCreators);
