@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -63,7 +63,7 @@ type State = {
 
 export const VISIBLE_TAGS = ['Community', 'Tech-Preview'];
 
-const EXCLUDED_TARGET_EDITOR_NAMES = ['che-idea'];
+const EXCLUDED_TARGET_EDITOR_NAMES = ['che-idea', 'che-theia'];
 
 export class SamplesListGallery extends React.PureComponent<Props, State> {
   private static sortByName(a: TargetEditor, b: TargetEditor): number {
