@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -12,6 +12,7 @@
 
 import { PROPAGATE_FACTORY_ATTRS, REMOTES_ATTR } from '../containers/Loader/const';
 import SessionStorageService, { SessionStorageKey } from '../services/session-storage';
+import { sanitizeLocation } from '../services/helpers/location';
 
 (function acceptNewFactoryLink(): void {
   if (window.location.pathname.startsWith('/dashboard/')) {
@@ -47,7 +48,7 @@ export function storePathIfNeeded(path: string) {
 }
 
 export function buildFactoryLoaderPath(url: string, appendUrl = true): string {
-  const fullUrl = new window.URL(url);
+  const fullUrl = sanitizeLocation<URL>(new window.URL(url));
 
   const initParams = PROPAGATE_FACTORY_ATTRS.map(paramName => {
     const paramValue = extractUrlParam(fullUrl, paramName);
