@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,7 +11,7 @@
  */
 
 import { Store } from 'redux';
-import common from '@eclipse-che/common';
+import common, { api, ApplicationId } from '@eclipse-che/common';
 import { lazyInject } from '../../inversify.config';
 import { AppState } from '../../store';
 import * as BannerAlertStore from '../../store/BannerAlert';
@@ -26,6 +26,8 @@ import * as SanityCheckStore from '../../store/SanityCheck';
 import * as DwPluginsStore from '../../store/Plugins/devWorkspacePlugins';
 import * as UserProfileStore from '../../store/UserProfile';
 import * as WorkspacesStore from '../../store/Workspaces';
+import * as EventsStore from '../../store/Events';
+import * as PodsStore from '../../store/Pods';
 import * as DevWorkspacesStore from '../../store/Workspaces/devWorkspaces';
 import * as WorkspacesSettingsStore from '../../store/Workspaces/Settings';
 import { ResourceFetcherService } from '../resource-fetcher';
@@ -40,6 +42,12 @@ import { Workspace } from '../workspace-adapter';
 import { WorkspaceRunningError, WorkspaceStoppedDetector } from './workspaceStoppedDetector';
 import { selectOpenVSXUrl } from '../../store/ServerConfig/selectors';
 import { selectEmptyWorkspaceUrl } from '../../store/DevfileRegistries/selectors';
+import { WebsocketClient } from '../dashboard-backend-client/websocketClient';
+import { selectEventsResourceVersion } from '../../store/Events/selectors';
+import { selectPodsResourceVersion } from '../../store/Pods/selectors';
+import { ChannelListener } from '../dashboard-backend-client/websocketClient/messageHandler';
+import { selectApplications } from '../../store/ClusterInfo/selectors';
+import { isAvailableEndpoint } from '../helpers/api-ping';
 
 /**
  * This class executes a few initial instructions
@@ -49,6 +57,9 @@ export default class Bootstrap {
   @lazyInject(IssuesReporterService)
   private readonly issuesReporterService: IssuesReporterService;
 
+  @lazyInject(WebsocketClient)
+  private readonly websocketClient: WebsocketClient;
+
   @lazyInject(DevWorkspaceClient)
   private readonly devWorkspaceClient: DevWorkspaceClient;
 
@@ -74,6 +85,7 @@ export default class Bootstrap {
       this.fetchInfrastructureNamespaces(),
       this.fetchWorkspaceSettings(),
       this.fetchServerConfig(),
+      this.fetchClusterInfo(),
     ]);
 
     const results = await Promise.allSettled([
@@ -85,9 +97,14 @@ export default class Bootstrap {
       this.updateDevWorkspaceTemplates(),
       this.fetchWorkspaces().then(() => {
         this.checkWorkspaceStopped();
-        return this.watchNamespaces();
+        return this.watchWebSocketDevWorkspaces();
+      }),
+      this.fetchEvents().then(() => {
+        this.watchWebSocketEvents();
+      }),
+      this.fetchPods().then(() => {
+        this.watchWebSocketPods();
       }),
-      this.fetchClusterInfo(),
       this.fetchClusterConfig(),
     ]);
 
@@ -149,26 +166,91 @@ export default class Bootstrap {
     }
   }
 
-  private async watchNamespaces(): Promise<void> {
+  private async watchWebSocketDevWorkspaces(): Promise<void> {
     const defaultKubernetesNamespace = selectDefaultNamespace(this.store.getState());
     const namespace = defaultKubernetesNamespace.name;
-    const { updateDevWorkspaceStatus, updateDeletedDevWorkspaces, updateAddedDevWorkspaces } =
-      DevWorkspacesStore.actionCreators;
-    const getResourceVersion = async () =>
-      selectDevWorkspacesResourceVersion(this.store.getState());
+    const { handleWebSocketMessage } = DevWorkspacesStore.actionCreators;
     const dispatch = this.store.dispatch;
     const getState = this.store.getState;
-    const callbacks = {
-      getResourceVersion,
-      updateDevWorkspaceStatus: statusUpdate =>
-        updateDevWorkspaceStatus(statusUpdate)(dispatch, getState, undefined),
-      updateDeletedDevWorkspaces: workspaceIds =>
-        updateDeletedDevWorkspaces(workspaceIds)(dispatch, getState, undefined),
-      updateAddedDevWorkspaces: workspaces =>
-        updateAddedDevWorkspaces(workspaces)(dispatch, getState, undefined),
+
+    await this.websocketClient.connect();
+
+    /* add listener and subscribe to devWorkspaces channel */
+
+    const listener: ChannelListener = message => {
+      handleWebSocketMessage(message)(dispatch, getState, undefined);
+    };
+    this.websocketClient.addChannelMessageListener(api.webSocket.Channel.DEV_WORKSPACE, listener);
+
+    // in case of reconnect we need to get the latest resource version
+    const getResourceVersion = () => {
+      const state = getState();
+      return selectDevWorkspacesResourceVersion(state);
     };
 
-    return await this.devWorkspaceClient.subscribeToNamespace({ namespace, callbacks });
+    this.websocketClient.subscribeToChannel(
+      api.webSocket.Channel.DEV_WORKSPACE,
+      namespace,
+      getResourceVersion,
+    );
+  }
+
+  private async watchWebSocketEvents(): Promise<void> {
+    const defaultKubernetesNamespace = selectDefaultNamespace(this.store.getState());
+    const namespace = defaultKubernetesNamespace.name;
+    const { handleWebSocketMessage } = EventsStore.actionCreators;
+    const dispatch = this.store.dispatch;
+    const getState = this.store.getState;
+
+    await this.websocketClient.connect();
+
+    /* add listener and subscribe to events channel */
+
+    const listener: ChannelListener = message => {
+      handleWebSocketMessage(message)(dispatch, getState, undefined);
+    };
+    this.websocketClient.addChannelMessageListener(api.webSocket.Channel.EVENT, listener);
+
+    // in case of reconnect we need to get the latest resource version
+    const getResourceVersion = () => {
+      const state = getState();
+      return selectEventsResourceVersion(state);
+    };
+
+    this.websocketClient.subscribeToChannel(
+      api.webSocket.Channel.EVENT,
+      namespace,
+      getResourceVersion,
+    );
+  }
+
+  private async watchWebSocketPods(): Promise<void> {
+    const defaultKubernetesNamespace = selectDefaultNamespace(this.store.getState());
+    const namespace = defaultKubernetesNamespace.name;
+    const { handleWebSocketMessage } = PodsStore.actionCreators;
+    const dispatch = this.store.dispatch;
+    const getState = this.store.getState;
+
+    await this.websocketClient.connect();
+
+    /* add listener and subscribe to pods channel */
+
+    const listener: ChannelListener = message => {
+      handleWebSocketMessage(message)(dispatch, getState, undefined);
+    };
+    this.websocketClient.addChannelMessageListener(api.webSocket.Channel.POD, listener);
+
+    // in case of reconnect we need to get the latest resource version
+    const getResourceVersion = () => {
+      const state = getState();
+      return selectPodsResourceVersion(state);
+    };
+
+    this.websocketClient.subscribeToChannel(
+      api.webSocket.Channel.POD,
+      namespace,
+      getResourceVersion,
+    );
   }
 
   private async fetchWorkspaces(): Promise<void> {
@@ -176,6 +258,16 @@ export default class Bootstrap {
     await requestWorkspaces()(this.store.dispatch, this.store.getState, undefined);
   }
 
+  private async fetchEvents(): Promise<void> {
+    const { requestEvents } = EventsStore.actionCreators;
+    await requestEvents()(this.store.dispatch, this.store.getState, undefined);
+  }
+
+  private async fetchPods(): Promise<void> {
+    const { requestPods } = PodsStore.actionCreators;
+    await requestPods()(this.store.dispatch, this.store.getState, undefined);
+  }
+
   private async fetchPlugins(): Promise<void> {
     const { requestPlugins } = PluginsStore.actionCreators;
     const settings = this.store.getState().workspacesSettings.settings;
@@ -222,12 +314,16 @@ export default class Bootstrap {
       const settings = this.store.getState().workspacesSettings.settings;
       const pluginRegistryUrl = settings['cheWorkspacePluginRegistryUrl'];
       const pluginRegistryInternalUrl = settings['cheWorkspacePluginRegistryInternalUrl'];
+      const clusterConsole = selectApplications(state).find(
+        app => app.id === ApplicationId.CLUSTER_CONSOLE,
+      );
       const updates = await this.devWorkspaceClient.checkForTemplatesUpdate(
         defaultNamespace,
         pluginsByUrl,
         pluginRegistryUrl,
         pluginRegistryInternalUrl,
         openVSXUrl,
+        clusterConsole,
       );
       if (Object.keys(updates).length > 0) {
         await this.devWorkspaceClient.updateTemplates(defaultNamespace, updates);
@@ -326,8 +422,12 @@ export default class Bootstrap {
     } catch (e) {
       if (e instanceof WorkspaceRunningError) {
         if (e.workspace.ideUrl) {
-          window.location.href = e.workspace.ideUrl;
-          return;
+          const ideUrl = e.workspace.ideUrl;
+          isAvailableEndpoint(ideUrl).then(isAvailable => {
+            if (isAvailable) {
+              window.location.replace(ideUrl);
+            }
+          });
         }
       } else {
         console.warn('Unable to check for stopped workspace.', e);
