@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -16,21 +16,23 @@ import devfileApi, { IDevWorkspacesList } from '../devfileApi';
 import { prefix } from './const';
 import { JSONSchema7 } from 'json-schema';
 
+export type Headers = { [key: string]: string };
+
 export async function createWorkspace(
   devworkspace: devfileApi.DevWorkspace,
-): Promise<devfileApi.DevWorkspace> {
+): Promise<{ devWorkspace: devfileApi.DevWorkspace; headers: Headers }> {
   try {
     const response = await axios.post(
       `${prefix}/namespace/${devworkspace.metadata.namespace}/devworkspaces`,
       { devworkspace },
     );
-    return response.data;
+    return { devWorkspace: response.data, headers: response.headers };
   } catch (e) {
     const errorMessage = helpers.errors.getMessage(e);
     if (errorMessage.startsWith('Unable to create devworkspace')) {
-      throw errorMessage;
+      throw new Error(errorMessage);
     }
-    throw `Failed to create a new workspace. ${errorMessage}`;
+    throw new Error(`Failed to create a new workspace. ${errorMessage}`);
   }
 }
 
@@ -41,7 +43,7 @@ export async function listWorkspacesInNamespace(
     const response = await axios.get(`${prefix}/namespace/${defaultNamespace}/devworkspaces`);
     return response.data;
   } catch (e) {
-    throw `Failed to fetch the list of devWorkspaces. ${helpers.errors.getMessage(e)}`;
+    throw new Error(`Failed to fetch the list of devWorkspaces. ${helpers.errors.getMessage(e)}`);
   }
 }
 
@@ -55,7 +57,9 @@ export async function getWorkspaceByName(
     );
     return response.data;
   } catch (e) {
-    throw `Failed to fetch workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to fetch workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`,
+    );
   }
 }
 
@@ -63,15 +67,17 @@ export async function patchWorkspace(
   namespace: string,
   workspaceName: string,
   patch: api.IPatch[],
-): Promise<devfileApi.DevWorkspace> {
+): Promise<{ devWorkspace: devfileApi.DevWorkspace; headers: Headers }> {
   try {
     const response = await axios.patch(
       `${prefix}/namespace/${namespace}/devworkspaces/${workspaceName}`,
       patch,
     );
-    return response.data;
+    return { devWorkspace: response.data, headers: response.headers };
   } catch (e) {
-    throw `Failed to update workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to update workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`,
+    );
   }
 }
 
@@ -79,7 +85,9 @@ export async function deleteWorkspace(namespace: string, workspaceName: string):
   try {
     await axios.delete(`${prefix}/namespace/${namespace}/devworkspaces/${workspaceName}`);
   } catch (e) {
-    throw `Failed to delete workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to delete workspace '${workspaceName}'. ${helpers.errors.getMessage(e)}`,
+    );
   }
 }
 
@@ -88,7 +96,7 @@ export async function getDockerConfig(namespace: string): Promise<api.IDockerCon
     const response = await axios.get(`${prefix}/namespace/${namespace}/dockerconfig`);
     return response.data;
   } catch (e) {
-    throw `Failed to fetch dockerconfig. ${helpers.errors.getMessage(e)}`;
+    throw new Error(`Failed to fetch dockerconfig. ${helpers.errors.getMessage(e)}`);
   }
 }
 
@@ -100,7 +108,7 @@ export async function putDockerConfig(
     const response = await axios.put(`${prefix}/namespace/${namespace}/dockerconfig`, dockerconfig);
     return response.data;
   } catch (e) {
-    throw `Failed to put dockerconfig. ${helpers.errors.getMessage(e)}`;
+    throw new Error(`Failed to put dockerconfig. ${helpers.errors.getMessage(e)}`);
   }
 }
 
@@ -110,7 +118,7 @@ export async function injectKubeConfig(namespace: string, devworkspaceId: string
       `${prefix}/namespace/${namespace}/devworkspaceId/${devworkspaceId}/kubeconfig`,
     );
   } catch (e) {
-    throw `Failed to inject kubeconfig. ${helpers.errors.getMessage(e)}`;
+    throw new Error(`Failed to inject kubeconfig. ${helpers.errors.getMessage(e)}`);
   }
 }
 
@@ -121,6 +129,8 @@ export async function getDevfileSchema(
     const response = await axios.get(`${prefix}/devfile?version=${schemaVersion}`);
     return response.data;
   } catch (e) {
-    throw `Failed to get devfile schema '${schemaVersion}'. ${helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to get devfile schema '${schemaVersion}'. ${helpers.errors.getMessage(e)}`,
+    );
   }
 }
