@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -81,12 +81,14 @@ export type CreateWorkspaceTab = 'quick-add' | 'custom-workspace';
 export enum LoaderTab {
   Progress = 0,
   Logs = 1,
+  Events = 2,
 }
 
 export enum WorkspaceDetailsTab {
   OVERVIEW = 'Overview',
   DEVFILE = 'Devfile',
-  DEVWRKSPACE = 'DevWorkspace',
+  DEVWORKSPACE = 'DevWorkspace',
+  EVENTS = 'Events',
 }
 
 export enum WorkspaceAction {
@@ -102,5 +104,3 @@ export enum WorkspaceAction {
 }
 
 export type UserPreferencesTab = 'container-registries' | 'git-services';
-
-export type WorkspacesLogs = Map<string, string[]>;
