@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,7 +14,7 @@ import mockAxios, { AxiosError } from 'axios';
 import { MockStoreEnhanced } from 'redux-mock-store';
 import { AnyAction } from 'redux';
 import { ThunkDispatch } from 'redux-thunk';
-import { ClusterInfo } from '@eclipse-che/common';
+import { ApplicationId, ClusterInfo } from '@eclipse-che/common';
 import { FakeStoreBuilder } from '../../__mocks__/storeBuilder';
 import { AppState } from '../..';
 import * as testStore from '..';
@@ -24,6 +24,7 @@ describe('clusterInfo store', () => {
   const clusterInfo: ClusterInfo = {
     applications: [
       {
+        id: ApplicationId.CLUSTER_CONSOLE,
         url: 'web/console/url',
         title: 'Web Console',
         icon: 'web/console/icon.png',
@@ -184,6 +185,7 @@ describe('clusterInfo store', () => {
         clusterInfo: {
           applications: [
             {
+              id: ApplicationId.CLUSTER_CONSOLE,
               url: 'web/console/url',
               title: 'Web Console',
               icon: 'web/console/icon.png',
