@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,7 +18,6 @@ import { createObject } from '../helpers';
 import fetchAndUpdateDevfileSchema from './fetchAndUpdateDevfileSchema';
 import devfileApi from '../../services/devfileApi';
 import { fetchResources, loadResourcesContent } from '../../services/registry/resources';
-import updateDevWorkspacePlugins from './updateDevWorkspacePlugins';
 import { AUTHORIZED, SanityCheckAction } from '../sanityCheckMiddleware';
 
 export const DEFAULT_REGISTRY = '/dashboard/devfile-registry/';
@@ -234,14 +233,14 @@ export const actionCreators: ActionCreators = {
           resource => resource.kind === 'DevWorkspace',
         ) as devfileApi.DevWorkspace;
         if (!devWorkspace) {
-          throw new Error('Failed to find a devworkspace in prebuilt resources.');
+          throw new Error('Failed to find a DevWorkspace in the fetched resources.');
         }
-        updateDevWorkspacePlugins(devWorkspace);
+
         const devWorkspaceTemplate = resources.find(
           resource => resource.kind === 'DevWorkspaceTemplate',
         ) as devfileApi.DevWorkspaceTemplate;
         if (!devWorkspaceTemplate) {
-          throw new Error('Failed to find a devworkspaceTemplate in prebuilt resources.');
+          throw new Error('Failed to find a DevWorkspaceTemplate in the fetched resources.');
         }
 
         dispatch({
