@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -29,6 +29,8 @@ import * as WorkspacesStore from './Workspaces';
 import * as DevWorkspacesStore from './Workspaces/devWorkspaces';
 import * as WorkspacesSettingsStore from './Workspaces/Settings';
 import * as GitOauthConfigStore from './GitOauthConfig';
+import * as EventsStore from './Events';
+import * as PodsStore from './Pods';
 
 // the top-level state object
 export interface AppState {
@@ -49,6 +51,8 @@ export interface AppState {
   userProfile: UserProfileStore.State;
   workspaces: WorkspacesStore.State;
   workspacesSettings: WorkspacesSettingsStore.State;
+  events: EventsStore.State;
+  pods: PodsStore.State;
 }
 
 export const reducers = {
@@ -69,6 +73,8 @@ export const reducers = {
   userProfile: UserProfileStore.reducer,
   workspaces: WorkspacesStore.reducer,
   workspacesSettings: WorkspacesSettingsStore.reducer,
+  events: EventsStore.reducer,
+  pods: PodsStore.reducer,
 };
 
 export type AppThunk<ActionType extends Action, ReturnType = void> = ThunkAction<
